package com.ruoyi.oa.mapper;

import java.util.List;
import com.ruoyi.oa.domain.CmcContractComment;

/**
 * cmc合同意见Mapper接口
 * 
 * @author cmc
 * @date 2024-04-19
 */
public interface CmcContractCommentMapper 
{
    /**
     * 查询cmc合同意见
     * 
     * @param contractId cmc合同意见主键
     * @return cmc合同意见
     */
    public List<CmcContractComment> selectCmcContractCommentByContractId(String contractId);

    /**
     * 查询cmc合同意见列表
     * 
     * @param cmcContractComment cmc合同意见
     * @return cmc合同意见集合
     */
    public List<CmcContractComment> selectCmcContractCommentList(CmcContractComment cmcContractComment);

    /**
     * 新增cmc合同意见
     * 
     * @param cmcContractComment cmc合同意见
     * @return 结果
     */
    public int insertCmcContractComment(CmcContractComment cmcContractComment);

    /**
     * 修改cmc合同意见
     * 
     * @param cmcContractComment cmc合同意见
     * @return 结果
     */
    public int updateCmcContractComment(CmcContractComment cmcContractComment);

    /**
     * 删除cmc合同意见
     * 
     * @param contractId cmc合同意见主键
     * @return 结果
     */
    public int deleteCmcContractCommentByContractId(String contractId);

    /**
     * 批量删除cmc合同意见
     * 
     * @param contractIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCmcContractCommentByContractIds(String[] contractIds);
}
