package com.ruoyi.web.controller.oa;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.oa.domain.CmcContractComment;
import com.ruoyi.oa.service.ICmcContractCommentService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * cmc合同意见Controller
 * 
 * @author cmc
 * @date 2024-04-19
 */
@RestController
@RequestMapping("/oa/contractComment")
public class CmcContractCommentController extends BaseController
{
    @Autowired
    private ICmcContractCommentService cmcContractCommentService;

    /**
     * 查询cmc合同意见列表
     */
    @GetMapping("/list")
    public TableDataInfo list(CmcContractComment cmcContractComment)
    {
        startPage();
        List<CmcContractComment> list = cmcContractCommentService.selectCmcContractCommentList(cmcContractComment);
        return getDataTable(list);
    }

    /**
     * 导出cmc合同意见列表
     */
    @Log(title = "cmc合同意见", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CmcContractComment cmcContractComment)
    {
        List<CmcContractComment> list = cmcContractCommentService.selectCmcContractCommentList(cmcContractComment);
        ExcelUtil<CmcContractComment> util = new ExcelUtil<CmcContractComment>(CmcContractComment.class);
        util.exportExcel(response, list, "cmc合同意见数据");
    }

    /**
     * 获取cmc合同意见详细信息
     */
    @GetMapping(value = "/{contractId}")
    public AjaxResult getInfo(@PathVariable("contractId") String contractId)
    {
        return success(cmcContractCommentService.selectCmcContractCommentByContractId(contractId));
    }

    /**
     * 新增cmc合同意见
     */
    @Log(title = "cmc合同意见", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CmcContractComment cmcContractComment)
    {
        return toAjax(cmcContractCommentService.insertCmcContractComment(cmcContractComment));
    }

    /**
     * 修改cmc合同意见
     */
    @Log(title = "cmc合同意见", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CmcContractComment cmcContractComment)
    {
        return toAjax(cmcContractCommentService.updateCmcContractComment(cmcContractComment));
    }

    /**
     * 删除cmc合同意见
     */
    @Log(title = "cmc合同意见", businessType = BusinessType.DELETE)
	@DeleteMapping("/{contractIds}")
    public AjaxResult remove(@PathVariable String[] contractIds)
    {
        return success(cmcContractCommentService.deleteCmcContractCommentByContractIds(contractIds));
    }
}
